<?php

namespace Teknisa\SUP\Modules\Parametros\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Method;
use Zeedhi\Framework\DataSource\DataSet;
use Exception;

class Cmp00600ParametrosComprasSuprimentosController extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $dataSourceManager;
    protected $crudService;
	protected $dataSourceNameToSave;
	protected $connection;
	
    protected $cdgrupoper;
    protected $cdfilial;
    protected $tipo;
    protected $newCode;

    public function __construct($crudService,  $environment, $dataSourceManager, $connection, $newCode) {
        $this->crudService       = $crudService;
        $this->environment       = $environment;
        $this->dataSourceManager = $dataSourceManager;
        $this->connection        = $connection;
        $this->newCode           = $newCode;
    }

    public function saveFilial (DTO\Request\Row $request, DTO\Response $response){
    	$this->saveFilialData($request, $response);
    }

    public function saveGrupoOperador (DTO\Request\DataSet $request, DTO\Response $response){
    	$this->saveGrupoOper($request, $response);
    }

    public function saveFilialData ($request, $response){
        
    	try {
            $this->dataSourceNameToSave = 'parasupri';
            parent::save($request,$response);
            
            //método separado para atualizar o campo IDUTLSUBGRPRODFIL
            $row = $request->getRow();
            $this->updateIDUTLSUBGRPRODFIL($row['IDUTLSUBGRPRODFIL'],$row['CDFILIAL']);
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function updateIDUTLSUBGRPRODFIL($P_IDUTLSUBGRPRODFIL, $P_CDFILIAL){
        $sql = "UPDATE PARASUPRI SET IDUTLSUBGRPRODFIL = :P_IDUTLSUBGRPRODFIL WHERE CDFILIAL = :P_CDFILIAL AND NRORG = :P_NRORG";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'P_IDUTLSUBGRPRODFIL'  => $P_IDUTLSUBGRPRODFIL,
                'P_CDFILIAL' => $P_CDFILIAL,
                'P_NRORG'       => $this->environment->getNrorg()
            )   
        );
        
    }
    
    
    private function removeOldData($row) {
        $sql = "DELETE FROM AUTGRUPOP WHERE IDAUTGRUPOP = :TIPO AND NRAUTGRUPOP = :NRAUTGRUPOP";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'TIPO'        => $row['TIPO'],
                'NRAUTGRUPOP' => substr(($row['CDFILIAL']),1,3)
            )
        );
    }
    
    private function insertNewData($row) {
        if ($row['CDGRUPOPER'] == ""){
            $this->removeOldData($row);
        }else{
            $sql = "INSERT INTO AUTGRUPOP (CDGRUPOPER,IDAUTGRUPOP,NRAUTGRUPOP,NRORG) VALUES (:CDGRUPOPER, :TIPO, :NRAUTGRUPOP, :NRORG)";
            $stmt = $this->connection->prepare($sql);
            $stmt->execute(
                array(
                    'CDGRUPOPER'  => $row['CDGRUPOPER'],
                    'TIPO'        => $row['TIPO'],
                    'NRAUTGRUPOP' => substr(($row['CDFILIAL']),1,3),
                    'NRORG'       => $this->environment->getNrorg(),
                )
            );
        }
    }
    
    public function saveGrupoOper($request,$response){
        
        try {
            $rows = $request->getDataSet()->getRows();
            foreach($rows as $row) {
                $this->removeOldData($row);
                $this->insertNewData($row);
            }
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function deletePermitPerfAcessAF($request,$response)
    {
        try {
            $row = $request->getRow();
            
            $sql = "SELECT NRAUTPERFACESSO FROM AUTPERFILACESSO WHERE NRPERFILACESSO = :P_NRPERFILACESSO AND IDAUTPERFACESSO = :P_IDAUTPERFACESSO AND NRORG = :P_NRORG";
            $stmt = $this->connection->prepare($sql);
            $stmt->execute(
                array(
                    'P_NRPERFILACESSO' => $row['NRPERFILACESSO'],
                    'P_IDAUTPERFACESSO'  => $row['IDAUTPERFACESSO'],
                    'P_NRORG' => $row['NRORG']
                )
            );
            
            $dataSet = $stmt->fetchAll();
            
            if (sizeof($dataSet) > 0) {
                $sql = "DELETE FROM AUTPERFILACESSO WHERE NRAUTPERFACESSO = :P_NRAUTPERFACESSO"; 
                $stmt = $this->connection->prepare($sql);
                $stmt->execute(
                array(
                        'P_NRAUTPERFACESSO' => $dataSet[0]['NRAUTPERFACESSO']
                    )
                );
            } else {
                $response->setError(new Error('Não foi possível remover essa permissão. A mesma não foi encontrada em nossa base de dados.', 500));
            }
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function deletePermit($request,$response){
         try {
            $this->dataSourceName = "autgrupop";
			$request = $this->crudService->buildDataSetIfRow($request, $this->dataSourceName);
			$dataSet = $request->getDataSet();
			$dataSet->setDataSourceName($this->dataSourceName);
			$this->crudService->delete($response, $dataSet);
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function savePermitPerfAcessAF($request, $response) {
        try {
            $row = $request->getRow();
            $sql = "SELECT * FROM AUTPERFILACESSO WHERE NRPERFILACESSO = :P_NRPERFILACESSO AND IDAUTPERFACESSO = :P_IDAUTPERFACESSO AND NRORG = :P_NRORG";
            $stmt = $this->connection->prepare($sql);
            $stmt->execute(
                array(
                    'P_NRPERFILACESSO' => $row['NRPERFILACESSO'],
                    'P_IDAUTPERFACESSO'  => $row['IDAUTPERFACESSO'],
                    'P_NRORG' => $row['NRORG']
                )
            );
            $dataSet = $stmt->fetchAll();

            if(sizeof($dataSet) == 0) {
                $this->dataSourceNameToSave = 'autperfilacesso';
                parent::save($request,$response);
            } else {
                $response->setError(new Error('Impossível adicionar. Registro já existe', 500));
            }
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function savePermitAF($request,$response){
        try {
            
            $row = $request->getRow();
            $sql = "SELECT * FROM AUTGRUPOP WHERE IDAUTGRUPOP = :IDAUTGRUPOP AND CDGRUPOPER = :CDGRUPOPER";
            $stmt = $this->connection->prepare($sql);
            $stmt->execute(
                array(
                    'IDAUTGRUPOP' => $row['IDAUTGRUPOP'],
                    'CDGRUPOPER'  => $row['CDGRUPOPER']
                    
                )
            );
            $dataSet = $stmt->fetchAll();
            if(sizeof($dataSet) == 0) {
                $this->dataSourceNameToSave = 'autgrupop';
                parent::save($request,$response);
            } else {
                $response->setError(new Error('Impossível adicionar. Registro já existe', 500));
            }
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function insertIdAutNeceComp($cdGrupoOper, $idPermissao, $peAlteQtdeSoli, $dtInclusao, $cdFilCentCmp)
    {
        $nrOrg      = $this->environment->getNrOrg();
        $cdOperador = $this->environment->getCdOperador();
        $code       = $this->newCode->getCodeByTableName("AUTGRUPOPSOLI", $nrOrg);
        $sql        = "INSERT INTO AUTGRUPOPSOLI ( NRAUTGRUPOPSOLI, CDGRUPOPER, IDAUTNECECOMP, PEALTEQTDESOLI, CDFILCENTCMP, NRORG, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU ) VALUES ( :NRAUTGRUPOPSOLI, :CDGRUPOPER , :IDPERMISSAO, :PEALTEQTDESOLI, :CDFILCENTCMP, :NRORG, 'S', :DTINCLUSAO, :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRORGULTATU, :CDOPERULTATU )";
        $stmt       = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'NRAUTGRUPOPSOLI' => $code,
                'CDGRUPOPER'      => $cdGrupoOper,
                'IDPERMISSAO'     => $idPermissao,
                'PEALTEQTDESOLI'  => $peAlteQtdeSoli,
                'CDFILCENTCMP'    => $cdFilCentCmp,
                'NRORG'           => $nrOrg,
                'DTINCLUSAO'      => $dtInclusao,
                'NRORGINCLUSAO'   => $nrOrg,
                'CDOPERINCLUSAO'  => $cdOperador,
                'NRORGULTATU'     => $nrOrg,
                'CDOPERULTATU'    => $cdOperador,
            )   
        );
    }
    
    public function insertIdAutLancSoli($cdGrupoOper, $idPermissao, $peAlteQtdeSoli, $dtInclusao, $cdFilCentCmp)
    {
        $nrOrg      = $this->environment->getNrOrg();
        $cdOperador = $this->environment->getCdOperador();
        $code       = $this->newCode->getCodeByTableName("AUTGRUPOPSOLI", $nrOrg);
        $sql        = "INSERT INTO AUTGRUPOPSOLI ( NRAUTGRUPOPSOLI, CDGRUPOPER, IDAUTLANCSOLI, PEALTEQTDESOLI, CDFILCENTCMP, NRORG, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU ) VALUES ( :NRAUTGRUPOPSOLI, :CDGRUPOPER , :IDPERMISSAO, :PEALTEQTDESOLI, :CDFILCENTCMP, :NRORG , 'S', :DTINCLUSAO, :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRORGULTATU, :CDOPERULTATU )";
        $stmt       = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'NRAUTGRUPOPSOLI' => $code,
                'CDGRUPOPER'      => $cdGrupoOper,
                'IDPERMISSAO'     => $idPermissao,
                'PEALTEQTDESOLI'  => $peAlteQtdeSoli,
                'CDFILCENTCMP'    => $cdFilCentCmp,
                'NRORG'           => $nrOrg,
                'DTINCLUSAO'      => $dtInclusao,
                'NRORGINCLUSAO'   => $nrOrg,
                'CDOPERINCLUSAO'  => $cdOperador,
                'NRORGULTATU'     => $nrOrg,
                'CDOPERULTATU'    => $cdOperador,
            )   
        );
    }
    
    public function insertIdAutAlteProdSoli($cdGrupoOper, $idPermissao, $peAlteQtdeSoli, $dtInclusao, $cdFilCentCmp)
    {
        $nrOrg      = $this->environment->getNrOrg();
        $cdOperador = $this->environment->getCdOperador();
        $code       = $this->newCode->getCodeByTableName("AUTGRUPOPSOLI", $nrOrg);
        $sql        = "INSERT INTO AUTGRUPOPSOLI ( NRAUTGRUPOPSOLI, CDGRUPOPER, IDAUTALTEPRODSOLI, PEALTEQTDESOLI, CDFILCENTCMP, NRORG, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU ) VALUES ( :NRAUTGRUPOPSOLI, :CDGRUPOPER , :IDPERMISSAO, :PEALTEQTDESOLI, :CDFILCENTCMP, :NRORG, 'S', :DTINCLUSAO, :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRORGULTATU, :CDOPERULTATU )";
        $stmt       = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'NRAUTGRUPOPSOLI' => $code,
                'CDGRUPOPER'      => $cdGrupoOper,
                'IDPERMISSAO'     => $idPermissao,
                'PEALTEQTDESOLI'  => $peAlteQtdeSoli,
                'CDFILCENTCMP'    => $cdFilCentCmp,
                'NRORG'           => $nrOrg,
                'DTINCLUSAO'      => $dtInclusao,
                'NRORGINCLUSAO'   => $nrOrg,
                'CDOPERINCLUSAO'  => $cdOperador,
                'NRORGULTATU'     => $nrOrg,
                'CDOPERULTATU'    => $cdOperador,
            )   
        );
    }
    
    public function insertIdAutAlteSoli($cdGrupoOper, $idPermissao, $peAlteQtdeSoli, $dtInclusao, $cdFilCentCmp)
    {
        $nrOrg      = $this->environment->getNrOrg();
        $cdOperador = $this->environment->getCdOperador();
        $code       = $this->newCode->getCodeByTableName("AUTGRUPOPSOLI", $nrOrg);
        $sql        = "INSERT INTO AUTGRUPOPSOLI ( NRAUTGRUPOPSOLI, CDGRUPOPER, IDAUTALTESOLI, PEALTEQTDESOLI, CDFILCENTCMP, NRORG, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU ) VALUES ( :NRAUTGRUPOPSOLI, :CDGRUPOPER , :IDPERMISSAO, :PEALTEQTDESOLI, :CDFILCENTCMP, :NRORG , 'S', :DTINCLUSAO, :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRORGULTATU, :CDOPERULTATU )";
        $stmt       = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'NRAUTGRUPOPSOLI' => $code,
                'CDGRUPOPER'      => $cdGrupoOper,
                'IDPERMISSAO'     => $idPermissao,
                'PEALTEQTDESOLI'  => $peAlteQtdeSoli,
                'CDFILCENTCMP'    => $cdFilCentCmp,
                'NRORG'           => $nrOrg,
                'DTINCLUSAO'      => $dtInclusao,
                'NRORGINCLUSAO'   => $nrOrg,
                'CDOPERINCLUSAO'  => $cdOperador,
                'NRORGULTATU'     => $nrOrg,
                'CDOPERULTATU'    => $cdOperador,
            )   
        );
    }
    
    public function deleteIdAutNeceComp($CDGRUPOPER,$IDPERMISSAO,$CDFILCENTCMP){
        $sql = "DELETE FROM AUTGRUPOPSOLI WHERE IDAUTNECECOMP = :IDPERMISSAO AND CDGRUPOPER = :CDGRUPOPER AND CDFILCENTCMP = :CDFILCENTCMP";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'CDGRUPOPER'  => $CDGRUPOPER,
                'IDPERMISSAO' => $IDPERMISSAO,
                'CDFILCENTCMP' => $CDFILCENTCMP
            )   
        );
    }
    public function deleteIdAutLancSoli($CDGRUPOPER,$IDPERMISSAO,$CDFILCENTCMP){
        $sql = "DELETE FROM AUTGRUPOPSOLI WHERE IDAUTLANCSOLI = :IDPERMISSAO AND CDGRUPOPER = :CDGRUPOPER AND CDFILCENTCMP = :CDFILCENTCMP";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'CDGRUPOPER'  => $CDGRUPOPER,
                'IDPERMISSAO' => $IDPERMISSAO,
                'CDFILCENTCMP' => $CDFILCENTCMP
            )   
        );
    }
    public function deleteIdAutAlteProdSoli($CDGRUPOPER,$IDPERMISSAO,$CDFILCENTCMP){
        $sql = "DELETE FROM AUTGRUPOPSOLI WHERE IDAUTALTEPRODSOLI = :IDPERMISSAO AND CDGRUPOPER = :CDGRUPOPER AND CDFILCENTCMP = :CDFILCENTCMP";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'CDGRUPOPER'  => $CDGRUPOPER,
                'IDPERMISSAO' => $IDPERMISSAO,
                'CDFILCENTCMP' => $CDFILCENTCMP
            )   
        );
    }
    public function deleteIdAutAlteSoli($CDGRUPOPER,$IDPERMISSAO,$CDFILCENTCMP){
        $sql = "DELETE FROM AUTGRUPOPSOLI WHERE IDAUTALTESOLI = :IDPERMISSAO AND CDGRUPOPER = :CDGRUPOPER AND CDFILCENTCMP = :CDFILCENTCMP";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'CDGRUPOPER'  => $CDGRUPOPER,
                'IDPERMISSAO' => $IDPERMISSAO,
                'CDFILCENTCMP' => $CDFILCENTCMP
            )   
        );
    }
    public function updatePEALTEQTDESOLI($CDGRUPOPER, $IDPERMISSAO, $PEALTEQTDESOLI,$CDFILCENTCMP){
        $sql = "UPDATE AUTGRUPOPSOLI SET PEALTEQTDESOLI = :PEALTEQTDESOLI WHERE CDGRUPOPER = :CDGRUPOPER AND (IDAUTNECECOMP = :IDPERMISSAO OR IDAUTLANCSOLI = :IDPERMISSAO OR IDAUTALTEPRODSOLI = :IDPERMISSAO OR IDAUTALTESOLI = :IDPERMISSAO ) AND CDFILCENTCMP = :CDFILCENTCMP";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'CDGRUPOPER'  => $CDGRUPOPER,
                'IDPERMISSAO' => $IDPERMISSAO,
                'PEALTEQTDESOLI' => $PEALTEQTDESOLI,
                'CDFILCENTCMP' => $CDFILCENTCMP
            )   
        );
        
    }
    
    public function deleteAllPermits($request,$response){
        $row = $request->getRow();
        $CDGRUPOPER = $row['CDGRUPOPER'];
        $IDPERMISSAO = $row['IDPERMISSAO'];
        $CDFILCENTCMP = $row['CDFILIAL'];
        $sql = "DELETE FROM AUTGRUPOPSOLI WHERE CDFILCENTCMP = :CDFILCENTCMP AND CDGRUPOPER = :CDGRUPOPER AND (IDAUTNECECOMP = :IDPERMISSAO OR IDAUTLANCSOLI = :IDPERMISSAO OR IDAUTALTEPRODSOLI = :IDPERMISSAO OR IDAUTALTESOLI = :IDPERMISSAO )";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'CDGRUPOPER'  => $CDGRUPOPER,
                'IDPERMISSAO' => $IDPERMISSAO,
                'CDFILCENTCMP' => $CDFILCENTCMP
            )   
        );
    }
    
    public function savePermitSoli($request, $response)
    {
        $row               = $request->getRow();
        $cdGrupoOper       = $row['CDGRUPOPER'];
        $idPermissao       = $row['IDPERMISSAO'];
        $peAlteQtdeSoli    = $row['PEALTEQTDESOLI'];
        $idAutNeceComp     = $row['IDAUTNECECOMP'];
        $idAutLancSoli     = $row['IDAUTLANCSOLI'];
        $idAutAlteProdSoli = $row['IDAUTALTEPRODSOLI'];
        $idAutAlteSoli     = $row['IDAUTALTESOLI'];
        $dtInclusao        = $row['DTINCLUSAO'];
        $cdFilCentCmp      = $row['CDFILIAL'];
        
        $sql  = "SELECT GRUPOPER.CDGRUPOPER, GRUPOPER.DSGRUPOPER, PERMISSAO.IDPERMISSAO, PERMISSAO.PEALTEQTDESOLI, CASE NVL(NECECOMP.IDAUTNECECOMP, 'N') WHEN 'N' THEN 'N' ELSE 'S' END IDAUTNECECOMP, CASE NVL(LANCSOLI.IDAUTLANCSOLI, 'N') WHEN 'N' THEN 'N' ELSE 'S' END IDAUTLANCSOLI, CASE NVL(ALTEPRODSOLI.IDAUTALTEPRODSOLI, 'N') WHEN 'N' THEN 'N' ELSE 'S' END IDAUTALTEPRODSOLI, CASE NVL(ALTESOLI.IDAUTALTESOLI, 'N') WHEN 'N' THEN 'N' ELSE 'S' END IDAUTALTESOLI, GRUPOPER.NRORG FROM (SELECT AUTGRUPOPSOLI.CDGRUPOPER, AUTGRUPOPSOLI.CDFILCENTCMP, AUTGRUPOPSOLI.PEALTEQTDESOLI, NVL(AUTGRUPOPSOLI.IDAUTNECECOMP, NVL(AUTGRUPOPSOLI.IDAUTLANCSOLI, NVL(AUTGRUPOPSOLI.IDAUTALTEPRODSOLI, AUTGRUPOPSOLI.IDAUTALTESOLI))) IDPERMISSAO FROM AUTGRUPOPSOLI, FILIAL WHERE AUTGRUPOPSOLI.CDFILCENTCMP = NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) AND FILIAL.CDFILIAL = :P_CDFILIAL AND AUTGRUPOPSOLI.CDGRUPOPER = :CDGRUPOPER AND NVL(AUTGRUPOPSOLI.IDAUTNECECOMP, NVL(AUTGRUPOPSOLI.IDAUTLANCSOLI, NVL(AUTGRUPOPSOLI.IDAUTALTEPRODSOLI, AUTGRUPOPSOLI.IDAUTALTESOLI))) = :IDPERMISSAO GROUP BY AUTGRUPOPSOLI.CDGRUPOPER, AUTGRUPOPSOLI.CDFILCENTCMP, AUTGRUPOPSOLI.PEALTEQTDESOLI, NVL(AUTGRUPOPSOLI.IDAUTNECECOMP, NVL(AUTGRUPOPSOLI.IDAUTLANCSOLI, NVL(AUTGRUPOPSOLI.IDAUTALTEPRODSOLI, AUTGRUPOPSOLI.IDAUTALTESOLI))) ) PERMISSAO INNER JOIN GRUPOPER ON PERMISSAO.CDGRUPOPER = GRUPOPER.CDGRUPOPER LEFT JOIN AUTGRUPOPSOLI NECECOMP ON PERMISSAO.CDGRUPOPER = NECECOMP.CDGRUPOPER AND PERMISSAO.IDPERMISSAO = NECECOMP.IDAUTNECECOMP AND PERMISSAO.CDFILCENTCMP = NECECOMP.CDFILCENTCMP LEFT JOIN AUTGRUPOPSOLI LANCSOLI ON PERMISSAO.CDGRUPOPER = LANCSOLI.CDGRUPOPER AND PERMISSAO.IDPERMISSAO = LANCSOLI.IDAUTLANCSOLI AND PERMISSAO.CDFILCENTCMP = LANCSOLI.CDFILCENTCMP LEFT JOIN AUTGRUPOPSOLI ALTEPRODSOLI ON PERMISSAO.CDGRUPOPER = ALTEPRODSOLI.CDGRUPOPER AND PERMISSAO.IDPERMISSAO = ALTEPRODSOLI.IDAUTALTEPRODSOLI AND PERMISSAO.CDFILCENTCMP = ALTEPRODSOLI.CDFILCENTCMP LEFT JOIN AUTGRUPOPSOLI ALTESOLI ON PERMISSAO.CDGRUPOPER = ALTESOLI.CDGRUPOPER AND PERMISSAO.IDPERMISSAO = ALTESOLI.IDAUTALTESOLI AND PERMISSAO.CDFILCENTCMP = ALTESOLI.CDFILCENTCMP ORDER BY SUBSTR(PERMISSAO.IDPERMISSAO, INSTR(PERMISSAO.IDPERMISSAO, '_', 1, 1) + 1, 1), PERMISSAO.IDPERMISSAO";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'IDPERMISSAO' => $idPermissao,
                'CDGRUPOPER'  => $cdGrupoOper,
                'P_CDFILIAL'  => $cdFilCentCmp
            )
        );
        $dataSet = $stmt->fetchAll();
        
        if ($row['__is_new']) {
            try {
                if (sizeof($dataSet) == 0) {
                    
                    if ($idAutNeceComp == 'S') {
                        $this->insertIdAutNeceComp($cdGrupoOper, $idPermissao, $peAlteQtdeSoli, $dtInclusao, $cdFilCentCmp);
                    }
                    
                    if ($idAutLancSoli == 'S') {
                        $this->insertIdAutLancSoli($cdGrupoOper, $idPermissao, $peAlteQtdeSoli, $dtInclusao, $cdFilCentCmp);
                    }
                    
                    if ($idAutAlteProdSoli == 'S') {
                        $this->insertIdAutAlteProdSoli($cdGrupoOper, $idPermissao, $peAlteQtdeSoli, $dtInclusao, $cdFilCentCmp);
                    }
                    
                    if ($idAutAlteSoli == 'S') {
                        $this->insertIdAutAlteSoli($cdGrupoOper, $idPermissao, $peAlteQtdeSoli, $dtInclusao, $cdFilCentCmp);
                    }
                    
                } else {
                    $response->setError(new Error('Impossível adicionar. Registro já existe', 500));
                }
            } catch (\Exception $e) {
    		    $response->setError(new Error($e->getMessage(), 500));
            }
        } else {
            $rowAntiga = $dataSet[0];
            if ($rowAntiga['IDAUTNECECOMP'] == 'S' && $idAutNeceComp == 'N') {
                $this->deleteIdAutNeceComp($cdGrupoOper, $idPermissao, $cdFilCentCmp);
                
            } elseif ($rowAntiga['IDAUTNECECOMP'] == 'N' && $idAutNeceComp == 'S') {
                $this->insertIdAutNeceComp($cdGrupoOper, $idPermissao, $peAlteQtdeSoli, $dtInclusao, $cdFilCentCmp);
            }
            
            if ($rowAntiga['IDAUTLANCSOLI'] == 'S' && $idAutLancSoli == 'N') {
                $this->deleteIdAutLancSoli($cdGrupoOper, $idPermissao, $cdFilCentCmp);
                
            } elseif ($rowAntiga['IDAUTLANCSOLI'] == 'N' && $idAutLancSoli == 'S') {
                $this->insertIdAutLancSoli($cdGrupoOper, $idPermissao, $peAlteQtdeSoli, $dtInclusao, $cdFilCentCmp);
            }
            
            if ($rowAntiga['IDAUTALTEPRODSOLI'] == 'S' && $idAutAlteProdSoli == 'N') {
                $this->deleteIdAutAlteProdSoli($cdGrupoOper, $idPermissao, $cdFilCentCmp);
                
            } elseif ($rowAntiga['IDAUTALTEPRODSOLI'] == 'N' && $idAutAlteProdSoli == 'S') {
                $this->insertIdAutAlteProdSoli($cdGrupoOper, $idPermissao, $peAlteQtdeSoli, $dtInclusao, $cdFilCentCmp);
            } 
            
            if ($rowAntiga['IDAUTALTESOLI'] == 'S' && $idAutAlteSoli == 'N') {
                $this->deleteIdAutAlteSoli($cdGrupoOper, $idPermissao, $cdFilCentCmp);
            } elseif ($rowAntiga['IDAUTALTESOLI'] == 'N' && $idAutAlteSoli == 'S') {
                $this->insertIdAutAlteSoli($cdGrupoOper, $idPermissao, $peAlteQtdeSoli, $dtInclusao, $cdFilCentCmp);
            }
            
            if ($rowAntiga['PEALTEQTDESOLI'] != $peAlteQtdeSoli) {
                $this->updatePEALTEQTDESOLI($cdGrupoOper, $idPermissao, $peAlteQtdeSoli, $cdFilCentCmp);
            }
        }
    }
    
    // FUNÇÕES DA ABA "FILIAL"
    
    public function saveDiversosFilial (DTO\Request\Row $request, DTO\Response $response){
        try {
            $row = $request->getRow();
            
            if ($row["IDTIPEMITGER"] == 3) {
                if($this->verificaClientePrincipal($row["CDFILIAL"]) == 0) {
                    $response->setError(new Error('Não há cliente principal cadastrado para a filial informada.', 500));
                }
            }
            
            $row['IDPERALTSAPR'] = $this->concatenaParametroMultiplo($row, 'IDPERALTSAPR', 3);

            $this->dataSourceNameToSave = 'parcmpsup';
            parent::save($request,$response);
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    private function concatenaParametroMultiplo($row, $nome, $quantidade)
    {
        $resultado = '';
        
        for ($i = 0; $i < $quantidade; $i++) {
            $parametro = $nome . $i;
            
            if (isset($row[$parametro])) {
                $resultado .= $row[$parametro];
            }
        }
        
        return $resultado;
    }
    
    public function verificaClientePrincipal($cdfilial) {
        $sql = "SELECT IDCLIENPRIN FROM CLIENFILIAL WHERE CDFILIAL = :CDFILIAL AND IDCLIENPRIN = 'S'";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'CDFILIAL' => $cdfilial
            )
        );
        $dataSet = $stmt->fetchAll();
        return sizeof($dataSet);
    }
    
    public function newFilialParasupri(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $this->dataSourceNameToSave = 'parasupri';
            parent::save($request,$response);
         
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function newFilialParcmpsup(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $this->dataSourceNameToSave = 'parcmpsup';
            parent::save($request,$response);
         
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function getCdgrupprodFilial(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $sql = "SELECT
                  CDGRUPPROD
                FROM PARASUPRI
                WHERE CDFILIAL = (SELECT
                    NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) AS CDFILCENTCMP
                  FROM FILIAL FILCENT,
                       FILIAL
                  WHERE FILIAL.CDFILIAL = :CDFILIAL
                  AND NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) = FILCENT.CDFILIAL)";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'CDFILIAL' => $row["CDFILIAL"]
            )
        );
        $dataSet = $stmt->fetchAll();
        if(sizeof($dataSet) == 0) {
            $cdgrupprod = null;
        } else {
            $cdgrupprod = $dataSet[0]["CDGRUPPROD"];
        }
        
        $cdgrupprod = array($cdgrupprod);
        $response->addDataSet(new DataSet ('cdgrupprod', $cdgrupprod));
    }
    
    public function getSubGrupoGeral(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $sql = "SELECT COUNT(*) AS QUANT
                FROM
                    (SELECT F.CDFILIAL
                     FROM FILIAL F
                     WHERE CDFILCENTCMP = :CDFILIAL
                         AND EXISTS
                             (SELECT P.CDGRUPPROD,
                                     P.CDSUBGRPROD
                              FROM PARCMPSUP P
                              WHERE P.CDFILIAL = F.CDFILIAL
                                  AND P.CDSUBGRPROD IS NOT NULL)
                     GROUP BY F.CDFILIAL
                     UNION SELECT F.CDFILIAL
                     FROM FILIAL F
                     WHERE CDFILIAL = :CDFILIAL
                         AND EXISTS
                             (SELECT P.CDGRUPPROD,
                                     P.CDSUBGRPROD
                              FROM PARCMPSUP P
                              WHERE P.CDFILIAL = F.CDFILIAL
                                  AND P.CDSUBGRPROD IS NOT NULL)
                     GROUP BY F.CDFILIAL)";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                'CDFILIAL' => $row["CDFILIAL"]
            )
        );
        $dataSet = $stmt->fetchAll();
        if(sizeof($dataSet) == 0) {
            $quant = 0;
        } else {
            $quant = $dataSet[0]["QUANT"];
        }
        $quant = array($quant);
        $response->addDataSet(new DataSet ('subGrupoGeral', $quant));
    }
    
    public function saveListaPrecoFilial(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $this->dataSourceNameToSave = 'parcmpsup';
            parent::save($request,$response);
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
        }
    }
    public function removeAllUnblockPermi($request,$response){
        $row = $request->getRow();
        $IDAUTNECECOMP = $row['IDBLOQALTNEC'];
        $IDBLOQALTSOLAUT = $row['IDBLOQALTSOLAUT'];
        $CDFILCENTCMP = $row['CDFILIAL'];
        $sql = "DELETE FROM AUTGRUPOPSOLI WHERE CDFILCENTCMP = :CDFILCENTCMP AND (:P_SOLICMP = 'N' AND ((IDAUTLANCSOLI IS NOT NULL) OR (IDAUTALTEPRODSOLI IS NOT NULL) OR (IDAUTALTESOLI IS NOT NULL)) OR (:P_NECECMP = 'N' AND IDAUTNECECOMP IS NOT NULL))";
        $stmt = $this->connection->prepare($sql);
        $stmt->execute(
            array(
                
                'P_SOLICMP'  => $IDBLOQALTSOLAUT,
                'P_NECECMP' => $IDAUTNECECOMP,
                'CDFILCENTCMP' => $CDFILCENTCMP
            )   
        );
    }
}