<?php

namespace Teknisa\SUP\Modules\Parametros\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Method;
use Zeedhi\Framework\DataSource\DataSet;
use Exception;

class ParametrosMercadumController extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $crudService;
    protected $dataSourceManager;
  	protected $connection;
	

    public function __construct($crudService,  $environment, $dataSourceManager, $connection) {
        $this->crudService       = $crudService;
        $this->environment       = $environment;
        $this->dataSourceManager = $dataSourceManager;
        $this->connection        = $connection;
    }
    
    public function saveMercadum(DTO\Request\Row $request, DTO\Response $response)
  	{
  		try {
        $row = $request->getRow();
  			$this->updateMercadum($row);
  			$response->addMessage(new Message("Operação realizada com sucesso."));
  		} catch (\Exception $e) {
  			$response->setError(new Error($e->getMessage(), 500));
  		}
  	}
	
    public function updateMercadum($row){
      $sql = "UPDATE PARAMMERCADUM  
              SET IDULTINTEGRAMERCADUM = :P_IDULTINTEGRAMERCADUM,
                  DSWEBSERVICE = :P_DSWEBSERVICE,
                  IDINTGPEDCOL = :P_IDINTGPEDCOL,
                  IDINTGAUTOFORN = :P_IDINTGAUTOFORN,
                  IDTIPOAUTOFORN = :P_IDTIPOAUTOFORN,
                  IDINTGCONTPAG = :P_IDINTGCONTPAG,
                  IDINTGNOTIFIC = :P_IDINTGNOTIFIC
                  
                WHERE NRORG    = :P_NRORG";
      $stmt = $this->connection->prepare($sql);
      $stmt->execute(
          array(

              'P_IDULTINTEGRAMERCADUM'   => $row['IDULTINTEGRAMERCADUM'],
              'P_DSWEBSERVICE'   => $row['DSWEBSERVICE'],
              'P_IDINTGPEDCOL'   => $row['IDINTGPEDCOL'],
              'P_IDINTGAUTOFORN'   => $row['IDINTGAUTOFORN'],
              'P_IDTIPOAUTOFORN'   => $row['IDTIPOAUTOFORN'],
              'P_IDINTGCONTPAG'   => $row['IDINTGCONTPAG'],
              'P_IDINTGNOTIFIC'   => $row['IDINTGNOTIFIC'],
              'P_NRORG'          => $row['NRORG']
          )   
      );
    }
    
    public function gerarChaveAcesso(DTO\Request $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            
            $nrorg = $row['NRORG'];
            $chave = md5(uniqid("TEKNISA", true));
            
            $this->salvaChaveAcesso($nrorg, $chave);
            
            $response->addMessage(new Message($chave));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage()));
        }
    }
    
    public function salvaChaveAcesso($nrorg, $chaveAcesso)
    {
        $sql = "UPDATE PARAMMERCADUM
                   SET DSTOKENINTGECO = :CHAVE_ACESSO
                 WHERE NRORG = :NRORG";
        
        $params = array(
            "NRORG" => $nrorg,
            "CHAVE_ACESSO" => $chaveAcesso
        );
         
        $query = $this->connection->prepare($sql);
        
        $query->execute($params);
    }
    
    public function createParametrosMercadum(DTO\Request $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            
            $nrorg = $this->environment->getNrorg();
            
            $webservice = $row['URL'];
            
            //Padrão a ser encontrado na string de url para separar a parte que precisamos, caso exista.
            $termo = '#';
            $pattern = '/' . $termo . '/'; 
            if (preg_match($pattern, $webservice)) {
              $webservice = explode('#', $webservice, 2);
              $webservice = $webservice[0];
            } 
            
            $chave = md5(uniqid("TEKNISA", true));
            
            $this->createParamsMercadum($nrorg, $chave, $webservice);
            
            $response->addMessage(new Message($chave));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage()));
        }
    }
    
    public function createParamsMercadum($nrorg, $chaveAcesso, $webservice)
    {
        $sql = "
                 INSERT INTO PARAMMERCADUM 
                 (NRORG, IDULTINTEGRAMERCADUM, DSWEBSERVICE,IDINTGPEDCOL,IDINTGAUTOFORN,IDTIPOAUTOFORN,IDINTGCONTPAG,IDINTGNOTIFIC, DSTOKENINTGECO) 
                 VALUES ( :NRORG,'N',:WEBSERVICE,'N', 'N','M','N','N', :CHAVE_ACESSO)

                 ";
        
        $params = array(
            "NRORG" => $nrorg,
            "CHAVE_ACESSO" => $chaveAcesso,
            "WEBSERVICE" => $webservice
        );
         
        $query = $this->connection->prepare($sql);
        
        $query->execute($params);
    }
    
    public function buscaFornecedores (){
        try {
            $query = "  SELECT  DF.NMUSUARIOECO, DF.CDOPERFORN, DF.DSLOGINECO, F.CDFORNECED, F.IDTPIJURFORN,
                                F.NRINSJURFORN, F.NMRAZSOCFORN, F.NMFANTFORN, F.NRINSESTFORN, E.IDTPENDEFORN, F.VRMINAUTFOR, F.VRPERVARDESCPREC, F.VRPERVARPREC,
                                E.CDPAIS, E.SGESTADO, E.CDMUNICIPIO, E.DSENDEFORN, E.NMBAIRFORN, E.NRCEPFORN
                        FROM FORNECEDOR F 
                                INNER JOIN ENDEFORN E ON F.CDFORNECED = E.CDFORNECED
                                INNER JOIN DADOSFORNECOMMERCE DF ON F.CDFORNECED = DF.CDFORNECED
                        WHERE E.IDTPENDEFORN = :P_IDTPENDEFORN";
                    
            $params = array(
                "P_IDTPENDEFORN" => "P"
            );        
            
            $std = $this->connection->prepare($query);
            $std->execute($params);
            return $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function buildFormattedData($row, $fornecedores){
		$mercadumIntegration = array();
		$dados = array();
		$dados['Nrorg'] = $row['NRORG'];
		$dados['Chave'] = $row['CHAVE'];
		
		if (count($fornecedores)) {
			$fornecedoresList = array();
			foreach ($fornecedores as $fornecedor) {
			    $dadosFornecedor = array();
				$dadosFornecedor['SUPPLIER']         =  $this->buildSupplier($fornecedor);
				$dadosFornecedor['SUPPLIER_ADDRESS'] =  $this->buildSupplierAddress($fornecedor);
				$dadosFornecedor['USERS']            =  $this->buildUsers($fornecedor);
				array_push($fornecedoresList, $dadosFornecedor);
			}
    	    $dados['Fornecedores'] = $fornecedoresList;
    	    $mercadumIntegration["mercadumIntegration"] = $dados;
			return $mercadumIntegration;
		} else {
			throw new \Exception("Não foram encontrados Fornecedores.");
		}
    }
    
    public function buildSupplier($fornecedor){
		$supplier = array(
			"SUPPLIER_ID"        => $fornecedor['CDFORNECED'],
			"TYPE_SUPPLIER"      => $fornecedor['IDTPIJURFORN'],
			"REGISTRATION"       => $fornecedor['NRINSJURFORN'],
			"CORPORATE_NAME"     => $fornecedor['NMRAZSOCFORN'],
			"SUPPLIER_NAME"      => $fornecedor['NMFANTFORN'],
			"STATE_REGISTRATION" => $fornecedor['NRINSESTFORN'],
			"MINIMUM_BILLING"    => $fornecedor['VRMINAUTFOR'],
			"DISCOUNT_VALUE"     => $fornecedor['VRPERVARDESCPREC'],
			"ADDITION_VALUE"     => $fornecedor['VRPERVARPREC']
		);
		return $supplier;
    }
     
    public function buildSupplierAddress($fornecedor){
		$supplierAddress = array(
			"SUPPLIER_ADDRESS_ID" => $fornecedor['IDTPENDEFORN'],
			"COUNTRY_CODE"        => $fornecedor['CDPAIS'],
			"STATE_CODE"          => $fornecedor['SGESTADO'],
			"CITY_CODE"           => $fornecedor['CDMUNICIPIO'],
			"ADDRESS"             => $fornecedor['DSENDEFORN'],
			"DISTRICT"            => $fornecedor['NMBAIRFORN'],
			"ZIP_CODE"            => $fornecedor['NRCEPFORN']
		); 
		return $supplierAddress;
    }
    
    public function buildUsers($fornecedor){
		$users = array(
			"USER_NAME"  => $fornecedor['NMUSUARIOECO'],
			"USER_ID"    => $fornecedor['CDOPERFORN'],
			"EMAIL"      => $fornecedor['DSLOGINECO']
		);
		return $users;
    }
    
    public function integracaoMercadum (DTO\Request\Row $request, DTO\Response $response){
        try{
            $row = $request->getRow();
            $fornecedores = $this->buscaFornecedores();
            $mercadumIntegration = $this->buildFormattedData($row,$fornecedores);
            $return = $this->enviaDadosIntegracao($mercadumIntegration);
        } catch (Exception $e) {
            $error = new DTO\Response\Error($e->getMessage(), $e->getCode());
		    $response->setError($error);
        }
    }
    
    public function enviaDadosIntegracao ($mercadumIntegration){
        try{
            $postdata = http_build_query($mercadumIntegration);
            $ch = curl_init();
            curl_setopt($ch,CURLOPT_URL, 'http://paulooliveira1.zeedhi.com/workfolder/mercadum/mercadum-fornecedor/backend/api/integration/suppliers');
            curl_setopt($ch,CURLOPT_POST, true);
            curl_setopt($ch,CURLOPT_POSTFIELDS, $postdata);
            curl_setopt($ch,CURLOPT_RETURNTRANSFER, true);
            $result = curl_exec($ch);
        } catch (Exception $e) {
            $error = new DTO\Response\Error($e->getMessage(), $e->getCode());
		    $response->setError($error);
        }
    }
    
}