<?php

namespace Teknisa\SUP\Services;

use Teknisa\SUP\Util\SupUtilities;
use Teknisa\SUP\Controllers\SendEmailController as EmailController;

class ReportWorkflowService
{
    public function __construct(SupUtilities $supUtilities, EmailController $emailController)
    {
        $this->supUtilities         = $supUtilities;
        $this->emailController = $emailController;
    }

    public function getApprover($orderData) {
        $sql = "SELECT NRALCADAGERFILI, CDOPERADOR, VRAPROVCMP, (SELECT MIN(B.VRAPROVCMP) FROM ALCADAGERFILI B WHERE B.CDFILIAL = ALCADAGERFILI.CDFILIAL AND B.NRCONFIGALCADA = ALCADAGERFILI.NRCONFIGALCADA AND B.VRAPROVCMP > ALCADAGERFILI.VRAPROVCMP) VRAPROVCMPMAX FROM ALCADAGERFILI WHERE CDFILIAL = :P_CDFILIAL AND NRCONFIGALCADA = :P_NRCONFIGALCADA AND VRAPROVCMP = (SELECT MIN(C.VRAPROVCMP) FROM ALCADAGERFILI C WHERE C.CDFILIAL = ALCADAGERFILI.CDFILIAL AND C.NRCONFIGALCADA = ALCADAGERFILI.NRCONFIGALCADA AND ((C.VRAPROVCMP > :P_VRAPROVCMP) OR :P_VRAPROVCMP = 'T')) ORDER BY VRAPROVCMP";
        $params = [
            "P_CDFILIAL"       => $orderData['CDFILDEST'],
            "P_VRAPROVCMP"     => $orderData['VRAPROVCMP'],
            "P_NRCONFIGALCADA" => $orderData['NRCONFIGALCADA']
        ];
        return $this->supUtilities->crud($sql, $params);
    }

    public function getUserFrom($userCode)
    {
        $sql = "SELECT NMOPERADOR, DSEMAILOPER FROM OPERADOR WHERE CDOPERADOR = :P_CDOPERADOR";
        $params = [ "P_CDOPERADOR" => $userCode ];
        return $this->supUtilities->crud($sql, $params);
    }

    public function getUserAddress($orderApproverCode )
    {
        $sql = "SELECT A.CDOPERADOR, G.NMOPERADOR, G.DSEMAILOPER FROM ALCADAGERFILI A, OPERADOR G WHERE A.NRALCADAGERFILI = :P_NRALCADAGERFILI AND A.CDOPERADOR = G.CDOPERADOR UNION SELECT O.CDOPERRELACAP CDOPERADOR, R.NMOPERADOR, R.DSEMAILOPER FROM ALCADAGERFILI A, ALCADAGEROPER O, OPERADOR R WHERE A.NRALCADAGERFILI = :P_NRALCADAGERFILI AND A.NRCONFIGALCADA = O.NRCONFIGALCADA AND A.CDFILIAL = O.CDFILIAL AND A.CDOPERADOR = O.CDOPERADOR AND O.CDOPERRELACAP = R.CDOPERADOR";
        $params = [ "P_NRALCADAGERFILI" => $orderApproverCode ];
        return $this->supUtilities->crud($sql, $params);
    }

    public function getUserLaunchCode($orderCode, $cdFildest)
    {
        $sql = "SELECT CDOPERLANCAF FROM AUTOFORNE WHERE CDFILDEST =:P_CDFILDEST AND NRAUTOFORN = :P_NRAUTOFORN";
        $params = [
            "P_NRAUTOFORN" => $orderCode,
            "P_CDFILDEST" => $cdFildest,
        ];
        return $this->supUtilities->crud($sql, $params)[0];
    }

    public function getUserLaunch($CDOPERRALACAF)
    {
        $sql = "SELECT CDOPERADOR, NMOPERADOR, DSEMAILOPER FROM OPERADOR WHERE CDOPERADOR = :P_CDOPERRALACAF";
        $params = [
            'P_CDOPERRALACAF' => $CDOPERRALACAF,
        ];
        return $this->supUtilities->crud($sql, $params);
    }

    public function getUserRelat($NRCONFIGALCADA, $CDFILDEST)
    {
        $sql = "SELECT ALCADAGEROPER.CDOPERADOR AS CDOPERADOR, OPERADOR.NMOPERADOR AS NMOPERADOR, OPERADOR.DSEMAILOPER AS DSEMAILOPER FROM ALCADAGEROPER, OPERADOR WHERE NRCONFIGALCADA = :P_NRCONFIGALCADA AND CDFILIAL = :P_CDFILDEST AND ALCADAGEROPER.CDOPERRELACAP = OPERADOR.CDOPERADOR";
        $params = [
            'P_NRCONFIGALCADA' => $NRCONFIGALCADA,
            'P_CDFILDEST' => $CDFILDEST,
        ];
        return $this->supUtilities->crud($sql, $params);
    }

    public function getUserGer($NRCONFIGALCADA, $CDFILDEST)
    {
        $sql = "SELECT ALCADAGERFILI.CDOPERADOR CDOPERADOR, GERENTE.NMOPERADOR NMOPERADOR, GERENTE.DSEMAILOPER DSEMAILOPER FROM ALCADAGERFILI, OPERADOR GERENTE WHERE ALCADAGERFILI.NRCONFIGALCADA = :P_NRCONFIGALCADA AND ALCADAGERFILI.CDFILIAL = :P_CDFILDEST AND ALCADAGERFILI.CDOPERADOR = GERENTE.CDOPERADOR";
        $params = [
            'P_NRCONFIGALCADA' => $NRCONFIGALCADA,
            'P_CDFILDEST' => $CDFILDEST,
        ];
        return $this->supUtilities->crud($sql, $params);
    }

    public function getTodosAprovadores($NRCONFIGALCADA, $CDFILDEST)
    {
        $sql = "SELECT NMOPERADOR, DSEMAILOPER FROM OPERADOR WHERE CDOPERADOR IN (SELECT CDOPERADOR FROM ALCADAGERFILI WHERE NRCONFIGALCADA = :NRCONFIGALCADA AND CDFILIAL = :CDFILIAL)";
        $params = [
            'NRCONFIGALCADA' => $NRCONFIGALCADA,
            'CDFILIAL' => $CDFILDEST,
        ];
        return $this->supUtilities->crud($sql, $params);
    }

    public function getTodosAprovadoresRelacionados($NRCONFIGALCADA, $CDFILDEST)
    {
        $sql = "SELECT NMOPERADOR, DSEMAILOPER FROM OPERADOR WHERE CDOPERADOR IN (SELECT CDOPERRELACAP FROM ALCADAGEROPER WHERE NRCONFIGALCADA = :NRCONFIGALCADA AND CDFILIAL = :CDFILIAL)";
        $params = [
            'NRCONFIGALCADA' => $NRCONFIGALCADA,
            'CDFILIAL' => $CDFILDEST,
        ];
        return $this->supUtilities->crud($sql, $params);
    }

    public function sendEmail($operFrom, $operAddress, $orderData, $subject, $justify)
    {
        $this->emailController->sendMail(
            array(
                "MOTIVO"           => $subject,
                "NMOPERADOR_FROM"  => $operFrom['NMOPERADOR'],
                "DSEMAILOPER_FROM" => $operFrom['DSEMAILOPER'],
                "NMOPERADOR"       => $operAddress['NMOPERADOR'],
                "DSEMAILOPER"      => $operAddress['DSEMAILOPER'],
                "IDTPDEMANDA"      => $orderData['IDTPDEMANDA'],
                "NRAUTOFORN"       => $orderData['NRAUTOFORN'],
                "NMFILIAL"         => $orderData['NMFILIAL'],
                "NMALCADA"         => $orderData['NMALCADA'],
                "IDCLASSIFIC"      => $orderData['IDCLASSIFIC'],
                "JUSTIFICATIVA"    => $justify
            )
        );
    }
    
    /**
    * 
    * @param string $approverID CDOPERADOR
    * @return []mixed a list of this user's devices
    * 
    */
    public function getApproverDevices($approverID){
        $sql = "SELECT TOKEN FROM DEVICE WHERE CDOPERADOR = :CDOPERADOR AND NRAPLICATIVO = 5";
        $params = [
              "CDOPERADOR" => $approverID
        ];
        return $this->supUtilities->crud($sql, $params);
    }
}
